pub enum OED_A {
_0 = 0,
_1 = 1,
}Expand description
Output Data Endian
Value on reset: 0
Variants
_0 = 0
0: Endian formats are the same between the chip and input data.
_1 = 1
1: Endian formats are different between the chip and input data.