OFTRG_R

Type Alias OFTRG_R 

pub type OFTRG_R = FieldReader<u8, OFTRG_A>;
Field OFTRG reader - Output FIFO Data Trigger Number

Aliased Type

pub struct OFTRG_R { /* private fields */ }

Implementations

Source

impl OFTRG_R

pub fn variant(&self) -> OFTRG_A

Get enumerated values variant

pub fn is_00(&self) -> bool

Checks if the value of the field is _00

pub fn is_01(&self) -> bool

Checks if the value of the field is _01

pub fn is_10(&self) -> bool

Checks if the value of the field is _10

pub fn is_11(&self) -> bool

Checks if the value of the field is _11