pub struct W(/* private fields */);Expand description
Register HL1CTRL2 writer
Implementations
Sourceimpl W
impl W
Sourcepub fn l1addr(&mut self) -> L1ADDR_W<'_, 0>
pub fn l1addr(&mut self) -> L1ADDR_W<'_, 0>
Bits 0:3 - LPM Token DeviceAddressThese bits specify the value to be set in the ADDR field of LPM token.
Sourcepub fn l1rwe(&mut self) -> L1RWE_W<'_, 12>
pub fn l1rwe(&mut self) -> L1RWE_W<'_, 12>
Bit 12 - LPM Token L1 RemoteWake EnableThese bits specify the value to be set in the RWE field of LPM token.
Methods from Deref<Target = W<HL1CTRL2_SPEC>>