Type Alias OFTRG_R
Source pub type OFTRG_R = FieldReader<u8, OFTRG_A>;
Field OFTRG reader - Output FIFO Data Trigger Number
pub struct OFTRG_R { }
Get enumerated values variant
Checks if the value of the field is _00
Checks if the value of the field is _01
Checks if the value of the field is _10
Checks if the value of the field is _11